@@ -35,8 +35,8 @@ class WebApp(Generic[GenConfig], ConfAble[GenConfig], SigAble, ChanAble, EnvAble
         self._environment = environment
         self._transports = transports
         self.manager = ProcManager()
-        cheat(self.manager, EnvAble, self._environment, nested=False)
         self.dispatcher = IDispatcher()
+        cheat(self.manager, EnvAble, self._environment, nested=False)
         self.channel = self.dispatcher.set_channel(self, ext_name="MasterChannel", master=True)
         self.name = name
         self.conf = config
@@ -121,36 +121,42 @@ class WebApp(Generic[GenConfig], ConfAble[GenConfig], SigAble, ChanAble, EnvAble
         cheat(self, EnvAble, self._environment)
 
         cheat(self, ConfAble, self.conf)
+
         if multiprocessing:
             self.manager.add_isolate_list(self._create_transport_isolates(workers=os.cpu_count() if fast else None))
-            tasks.extend(self.manager.perform())
+            # tasks.extend(self.manager.perform())
+            await self.manager.run()
 
         if self.scheduler:
             self.channel.add_event_listener(TaskEvent.message_type, self.scheduler.add_task)
-            tasks.extend(self.scheduler.perform())
+            # tasks.extend(self.scheduler.perform())
+            await self.scheduler.run()
 
-        # TODO FIX:
-        if not multiprocessing:
-            united_socket = ISocket(self._transports[0].conf.socket.host, self._transports[0].conf.socket.port)
-            for transport in self._transports:
-                tasks.extend(transport.perform(united_socket))
+        # # TODO FIX:
+        # if not multiprocessing:
+        #     united_socket = ISocket(self._transports[0].conf.socket.host, self._transports[0].conf.socket.port)
+        #     for transport in self._transports:
+        #         tasks.extend(transport.perform(united_socket))
 
         tasks.extend(self.dispatcher.perform())
         tasks.append(self.channel.listen_consume())
 
-        def sig_handler(sig, frame):
+        async def sig_handler():
             loguru.logger.info(
-                f"{self.name} Received signal {Signals(sig).name}. Shutting down.")
+                f"{self.name} Received shutdown signal , exit")
+            await call_signals(self, SignalType.AFTER_APP_STOP, app=self)
             self.scheduler.stop()
             self.manager.stop()
             exit(0)
 
-        signal(SIGINT, lambda s, f: sig_handler(s, f))
-        signal(SIGTERM, lambda s, f: sig_handler(s, f))
+        loop = asyncio.get_event_loop()
+        loop.add_signal_handler(SIGINT, lambda: asyncio.create_task(sig_handler()))
+        loop.add_signal_handler(SIGTERM, lambda: asyncio.create_task(sig_handler()))
+
+        await self.env.init()
 
         await call_signals(self, SignalType.BEFORE_APP_RUN, app=self)
         await asyncio.wait(tasks)
-        await call_signals(self, SignalType.AFTER_APP_STOP, app=self)
         await self._environment.shutdown()
 
 
