@@ -340,7 +340,7 @@ class SigAble:
 
 
 async def call_signals(obj: SigAble, typed: SignalType, *args, nested: bool = False, **kwargs):
-    if hasattr(obj, "signals") and obj.signals:
+    if hasattr(obj, "signals") and obj.signals and obj.signals.get(typed):
         for signal in obj.signals[typed]:
             await signal(*args, **kwargs)
         if nested:
